StoreTxn class abstract interface

Tables available inside one transaction.

Properties

hashCode → int
The hash code for this object.
no setterinherited
meta → MetaTable
no setter
ops → OpLog
no setter
records → RecordTable
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited