ErrorInfo class final
A classified error, safe to persist (messages must already be redacted).
Constructors
Properties
- ambiguous → bool
-
True when the server may have applied the request (e.g. a timeout after
the request was written). Drives the
Deliveryrules.final - code → String
-
Machine-readable code:
timeout,http_503,validation, ...final - hashCode → int
-
The hash code for this object.
no setterinherited
- httpStatus → int?
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited